@@ -2,15 +2,25 @@
 # @Author: Kelvin
 # @Date:   2021-02-06 13:18:58
 # @Last Modified by:   Kelvin
-# @Last Modified time: 2022-05-18 16:18:14
-from typing import Union, Sequence, Tuple
+# @Last Modified time: 2022-06-18 14:31:46
+"""logging module."""
+from typing import Sequence
 
-modules = ['dandelion', 'pandas', 'numpy', 'matplotlib',
-           'networkx', 'scipy', 'distance', 'polyleven']
+modules = [
+    "dandelion",
+    "pandas",
+    "numpy",
+    "matplotlib",
+    "networkx",
+    "scipy",
+    "distance",
+    "polyleven",
+]
 
 
 # borrowed from scanpy's logging module
 def _versions_dependencies(dependencies: Sequence):
+    """Version dependencies."""
     for mod in dependencies:
         mod_name, dist_name = mod if isinstance(mod, tuple) else (mod, mod)
         try:
@@ -21,20 +31,22 @@ def _versions_dependencies(dependencies: Sequence):
 
 
 def print_versions(dependencies: Sequence = modules):
-    '''
+    """
     Versions that are essential for dandelion's operation.
-    '''
-    print(' '.join(
-        f'{mod}=={ver}'
-        for mod, ver in _versions_dependencies(dependencies)
-    ))
+    """
+    print(
+        " ".join(
+            f"{mod}=={ver}" for mod, ver in _versions_dependencies(dependencies)
+        )
+    )
 
 
 def print_header(dependencies: Sequence = modules):
-    '''
+    """
     Versions that are essential for dandelion's operation.
-    '''
-    print(' '.join(
-        f'{mod}=={ver}'
-        for mod, ver in _versions_dependencies(dependencies)
-    ))
+    """
+    print(
+        " ".join(
+            f"{mod}=={ver}" for mod, ver in _versions_dependencies(dependencies)
+        )
+    )
